@@ -6,21 +6,39 @@
 namespace colourvalues {
 namespace scale {
 
-  inline Rcpp::NumericVector range(Rcpp::NumericVector& x) {
-    Rcpp::NumericVector rng(2);
-    rng[0] = min(na_omit(x));
-    rng[1] = max(na_omit(x));
-    return rng;
-  }
+  inline Rcpp::NumericVector minmax( Rcpp::NumericVector& x ) {
+    int n = x.size();
 
+    double min = 0;
+    double max = 0;
+    bool first_value = false;
+
+    for( int i = 0; i < n; i++) {
+
+      if( !ISNAN( x[i] ) ) {
+        if( !first_value ) {
+          min = x[i];
+          max = x[i];
+          first_value = true;
+        } else {
+          if( x[i] < min ) {
+            min = x[i];
+          } else if ( x[i] > max) {
+            max = x[i];
+          }
+        }
+      }
+    }
+    return Rcpp::NumericVector::create(min, max);
+  }
 
   // Always rescales to (0, 1)
   // used for variables
   inline void rescale( Rcpp::NumericVector& x ) {
     int n = x.size();
     //::NumericVector rescaled(n);
-    Rcpp::NumericVector rng = range(x);
-    Rcpp::NumericVector diff_from = Rcpp::diff(rng); // should only be one value!
+    Rcpp::NumericVector rng = minmax( x );
+    Rcpp::NumericVector diff_from = Rcpp::diff( rng ); // should only be one value!
 
     double this_diff = diff_from[0] == 0 ? 1.0 : diff_from[0];
 
@@ -29,7 +47,7 @@ namespace scale {
     double this_range = rng[0];
 
     for (i = 0; i < n; i++) {
-      x[i] = (x[i] - this_range) * this_diff;
+      x[i] = ( x[i] - this_range ) * this_diff;
     }
     //return rescaled;
   }
